@@ -1,3 +1,4 @@
+"""Submodule with utilities for plotting barplots."""
 from .save_picture import save_picture
 from .get_axes import get_axes
 from .text_positions import text_positions
@@ -5,7 +6,7 @@ from .plot_bars import plot_bars
 from .get_levels import get_levels
 from .remove_duplicated_legend_labels import remove_duplicated_legend_labels
 from .plot_bar_labels import plot_bar_labels
-from .get_max_bar_lenght import get_max_bar_lenght
+from .get_max_bar_length import get_max_bar_length
 
 
 __all__ = [
@@ -16,5 +17,5 @@ __all__ = [
     "get_levels",
     "remove_duplicated_legend_labels",
     "plot_bar_labels",
-    "get_max_bar_lenght"
+    "get_max_bar_length"
 ]
\ No newline at end of file
